![SoundScrape!](http://i.imgur.com/fEFQqlK.png)

SoundScrape
==============

**SoundScrape** makes it super easy to download artists from SoundCloud. It even automatically creates ID3 tags as well, which is handy.

Usage
---------

First, install it:

```bash
pip install soundscrape
```

Then, just call soundscrape and the name of the artist you want to scrape:

```bash
soundscrape kaiwaichi
```

And you're done! Hooray!

Issues
-------

There's probably a lot more that can be done to improve this. Please file issues if you find them!
